@@ -17,6 +17,7 @@ import (
 	"os"
 	"path/filepath"
 	"strings"
+	"time"
 
 	"github.com/google/renameio"
 	"github.com/mattn/go-isatty"
@@ -129,6 +130,10 @@ func parseKey(r io.Reader) (*rsa.PublicKey, error) {
 		return nil, fmt.Errorf("Expected RSA public key but found %v", certs[0].PublicKey)
 	}
 
+	if time.Now().After(certs[0].NotAfter) {
+		return nil, fmt.Errorf("failed to encrypt using an expired certificate on %v", certs[0].NotBefore.Format("January 2, 2006"))
+	}
+
 	return cert, nil
 }
 
@@ -193,6 +198,7 @@ func openCertLocal(filenameOrURI string) (io.ReadCloser, error) {
 	if ok, err := isFilename(filenameOrURI); err != nil {
 		return nil, err
 	} else if ok {
+		// #nosec G304 -- should open user provided file
 		return os.Open(filenameOrURI)
 	}
 	return openCertURI(filenameOrURI)
@@ -429,7 +435,15 @@ func decodeSealedSecret(codecs runtimeserializer.CodecFactory, b []byte) (*ssv1a
 }
 
 func sealMergingInto(in io.Reader, filename string, codecs runtimeserializer.CodecFactory, pubKey *rsa.PublicKey, scope ssv1alpha1.SealingScope, allowEmptyData bool) error {
-	b, err := ioutil.ReadFile(filename)
+	// #nosec G304 -- should open user provided file
+	f, err := os.OpenFile(filename, os.O_RDWR, 0)
+	if err != nil {
+		return err
+	}
+	// #nosec G307 -- we are explicitly managing a potential error from f.Close() at the end of the function
+	defer f.Close()
+
+	b, err := io.ReadAll(f)
 	if err != nil {
 		return err
 	}
@@ -468,13 +482,21 @@ func sealMergingInto(in io.Reader, filename string, codecs runtimeserializer.Cod
 	if err := sealedSecretOutput(&out, codecs, orig); err != nil {
 		return err
 	}
-	// On windows the permission bits are used also when truncating existing files
-	// (see https://github.com/golang/go/issues/38225)
-	// Thus we need to set some reasonable permissions.
-	// The actual permissions will be filtered by the user's umask.
-	// We still drop any permissions to the other group because despite the sealed secret
-	// being encrypted, we still don't know how the end users feel about it.
-	return ioutil.WriteFile(filename, out.Bytes(), 0660)
+
+	if err := f.Truncate(0); err != nil {
+		return err
+	}
+	if _, err := f.Seek(0, 0); err != nil {
+		return err
+	}
+	if _, err := io.Copy(f, &out); err != nil {
+		return err
+	}
+	// we explicitly call f.Close() to return a pontential error when closing the file that wouldn't be returned in the deferred f.Close()
+	if err := f.Close(); err != nil {
+		return err
+	}
+	return nil
 }
 
 func encryptSecretItem(w io.Writer, secretName, ns string, data []byte, scope ssv1alpha1.SealingScope, pubKey *rsa.PublicKey) error {
@@ -500,6 +522,7 @@ func parseFromFile(s string) (string, string) {
 }
 
 func readPrivKeysFromFile(filename string) ([]*rsa.PrivateKey, error) {
+	// #nosec G304 -- should open user provided file
 	b, err := ioutil.ReadFile(filename)
 	if err != nil {
 		return nil, err
@@ -622,6 +645,7 @@ func run(ctx context.Context, w io.Writer, inputFileName, outputFileName, secret
 
 	var input io.Reader = os.Stdin
 	if inputFileName != "" {
+		// #nosec G304 -- should open user provided file
 		f, err := os.Open(inputFileName)
 		if err != nil {
 			return nil
@@ -724,6 +748,7 @@ func run(ctx context.Context, w io.Writer, inputFileName, outputFileName, secret
 			}
 
 			_, filename := parseFromFile(fromFile[0])
+			// #nosec G304 -- should open user provided file
 			data, err = ioutil.ReadFile(filename)
 		} else {
 			if isatty.IsTerminal(os.Stdin.Fd()) {
